@@ -10,7 +10,7 @@ package EB::Shell;
 use strict;
 use warnings;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.105 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.109 $ =~ /(\d+)/g;
 
 use EB;
 
@@ -707,7 +707,7 @@ sub _do_btwaangifte {
 	       ], $opts)
       or goto &_help_btwaangifte;
 
-    if ( lc($args[-1]) eq "definitief" ) {
+    if ( @args && lc($args[-1]) eq "definitief" ) {
 	$opts->{close} = 1;
 	pop(@args);
     }
@@ -746,6 +746,7 @@ Opties:
   --noreport                  Geen rapportage. Dit is enkel zinvol samen
                               met --definitief om de afgesloten BTW periode
                               aan te passen.
+  --noround		      Alle bedragen zonder af te ronden.
 
 Zie verder "help rapporten" voor algemene informatie over aan te maken
 rapporten.
@@ -967,26 +968,48 @@ sub do_export {
 	       [ 'dir=s',
 		 'file|output=s',
 		 'boekjaar=s',
+		 'xaf=s',
 		 'single',
 		 'explicit',
 		 'totals!',
 	       ], $opts)
       or goto &help_export;
 
-    if ( defined($opts->{dir}) && defined($opts->{file}) ) {
-	warn("?"._T("Opties --dir en --file sluiten elkaar uit")."\n");
+    my $t = 0;
+    $t++ if defined($opts->{dir});
+    $t++ if defined($opts->{file});
+    $t++ if defined($opts->{xaf});
+    if ( $t > 1 ) {
+	warn("?"._T("Opties --dir, --file en --xaf sluiten elkaar uit")."\n");
 	return;
     }
-    if ( !defined($opts->{dir}) && !defined($opts->{file}) ) {
-	warn("?"._T("Specifieer --dir of --file")."\n");
+    if ( $t != 1 ) {
+	warn("?"._T("Specifieer --dir, --file of --xaf")."\n");
 	return;
     }
 
     return unless argcnt(@args, 0);
     check_open(1);
 
-    require EB::Export;
-    EB::Export->export($opts);
+    if ( $opts->{xaf} ) {
+	if ( findlib "Export/XAF.pm" ) {
+	    require EB::Export::XAF;
+	    # XAF bevat altijd maar n boekjaar.
+	    $opts->{boekjaar} ||= $bky;
+	    EB::Export::XAF->export($opts);
+	}
+	else {
+	    warn("?"._T("Export naar XML Auditfile Financieel is niet beschikbaar")."\n");
+	}
+    }
+    else {
+	if ( $opts->{boekjaar} ) {
+	    warn("?"._T("Optie --boekjaar wordt niet ondersteunt door deze export")."\n");
+	return;
+	}
+	require EB::Export;
+	EB::Export->export($opts);
+    }
 
     return;
 }
@@ -1000,11 +1023,13 @@ Exporteert de complete administratie.
 Opties:
 
   --file=<bestand>          Selecteer uitvoerbestand
-  --dir=<directory>           Selecteer uitvoerdirectory
-  --boekjaar=<code>           Selecteer boekjaar
+  --dir=<directory>         Selecteer uitvoerdirectory
+  --xaf=<bestand>           Export XML Auditfile Financieel
+  --boekjaar=<code>         Selecteer boekjaar (alleen met --xaf)
 
-Er moet of een --file of een --dir optie worden opgegeven.
-Zonder --boekjaar selectie wordt de gehele administratie gexporteerd.
+Er moet een --file, --dir of een --xaf optie worden opgegeven.
+De XAF export exporteert altijd n enkel boekjaar. Voor de andere
+exports wordt altijd de gehele administratie gexporteerd.
 Eventueel bestaande files worden overschreven.
 EOS
 }
